summaryrefslogtreecommitdiffstats
path: root/media/libstagefright/MediaCodecListOverrides.h
diff options
context:
space:
mode:
authorRonghua Wu <ronghuawu@google.com>2015-04-21 14:23:06 -0700
committerRonghua Wu <ronghuawu@google.com>2015-05-08 09:51:26 -0700
commit9ba21b9418d10ddcc39f08901e24fbf43d82b2bc (patch)
tree363f0598085516cf16ddd4ee5df2d1043e2955da /media/libstagefright/MediaCodecListOverrides.h
parentba21a9ac7b6b76f85681cfb5e756e947c0ae3b53 (diff)
downloadframeworks_av-9ba21b9418d10ddcc39f08901e24fbf43d82b2bc.zip
frameworks_av-9ba21b9418d10ddcc39f08901e24fbf43d82b2bc.tar.gz
frameworks_av-9ba21b9418d10ddcc39f08901e24fbf43d82b2bc.tar.bz2
libstagefright: config resource manager with secure codec co-existing policy.
Bug: 19620911 Change-Id: I0d729782c1622f23e9c37b7a9231e58e3f807470
Diffstat (limited to 'media/libstagefright/MediaCodecListOverrides.h')
-rw-r--r--media/libstagefright/MediaCodecListOverrides.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/media/libstagefright/MediaCodecListOverrides.h b/media/libstagefright/MediaCodecListOverrides.h
index c4758fa..e350d2a 100644
--- a/media/libstagefright/MediaCodecListOverrides.h
+++ b/media/libstagefright/MediaCodecListOverrides.h
@@ -35,9 +35,10 @@ bool splitString(const AString &s, const AString &delimiter, AString *s1, AStrin
// profile codecs and save the result to xml file named kProfilingResults.
void profileCodecs(const Vector<sp<MediaCodecInfo>> &infos);
// profile codecs and save the result to encoder_results and decoder_results.
void profileCodecs(
const Vector<sp<MediaCodecInfo>> &infos,
+ CodecSettings *global_results,
KeyedVector<AString, CodecSettings> *encoder_results,
KeyedVector<AString, CodecSettings> *decoder_results,
bool forceToMeasure = false);
@@ -35,9 +35,10 @@ bool splitString(const AString &s, const AString &delimiter, AString *s1, AStrin
// profile codecs and save the result to xml file named kProfilingResults.
void profileCodecs(const Vector<sp<MediaCodecInfo>> &infos);
-// profile codecs and save the result to encoder_results and decoder_results.
+// profile codecs and save the result to global_results, encoder_results and decoder_results.
void profileCodecs(
const Vector<sp<MediaCodecInfo>> &infos,